BitboardSearch class

Constructors

BitboardSearch(Position pos, {int evaluator(Position)?, List<int>? repetitionHistory})

Properties

hashCode int
The hash code for this object.
no setterinherited
pos Position
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Iterative deepening to maxDepth. With a timeBudget the search returns the best move from the last fully completed depth once time is spent.
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited